@@ -1,18 +1,17 @@
 package                                # Hide from PAUSE.
   WiX3::Types;
 
-use 5.008003;
+use 5.008001;
 use MooseX::Types -declare => [ qw(
 	  Host Tracelevel IsTag _YesNoType YesNoType ComponentGuidType PositiveInt
-	  NonNegativeInt TraceObject
-	  EnumRemoveFolderOn EnumEnvironmentAction EnumRegistryKeyAction
-	  EnumRegistryValueType EnumRegistryRootType EnumRegistryValueAction
+	  NonNegativeInt TraceObject EnumRemoveFolderOn
 	  ) ];
 use Regexp::Common 2.105;
 use MooseX::Types::Moose qw( Str Int Bool HashRef );
 use Readonly 1.03 qw( Readonly );
 
-our $VERSION = '0.011';
+our $VERSION = '0.009100';
+$VERSION =~ s/_//ms;
 
 # Assemble the GUID regex from pieces.
 Readonly my $HEX              => '0-9A-F';
@@ -35,24 +34,13 @@ subtype Host, as Str, where {
 
 enum EnumRemoveFolderOn, qw( install uninstall both );
 
-enum EnumEnvironmentAction, qw( create set remove );
-
-enum EnumRegistryKeyAction, qw( create createAndRemoveOnUninstall none );
-
-enum EnumRegistryRootType, qw( HKMU HKCR HKCU HKLM HKU );
-
-enum EnumRegistryValueType,
-  qw( string integer binary expandable multiString );
-
-enum EnumRegistryValueAction, qw( append prepend write );
-
 subtype IsTag, as role_type 'WiX3::XML::Role::Tag';
 
 subtype TraceObject, as class_type 'WiX3::Trace::Object';
 
 subtype Tracelevel,
   as Int,
-  where { ( $_ >= 0 ) && ( $_ <= 5 ) }, ## no critic (ProhibitMagicNumbers)
+  where { ( $_ >= 0 ) && ( $_ <= 5 ) },
   message {"The tracelevel you provided, $_, was not valid."};
 
 subtype _YesNoType,
