@@ -1,20 +1,20 @@
 package WiX3::XML::Component;
 
-use 5.008003;
+use 5.008001;
 
 # Must be done before Moose, or it won't get picked up.
 use metaclass (
 	metaclass   => 'Moose::Meta::Class',
 	error_class => 'WiX3::Util::Error',
 );
-use Moose 2;
+use Moose;
 use Params::Util qw( _STRING _IDENTIFIER );
 use WiX3::Types qw( YesNoType ComponentGuidType );
-use WiX3::XML::TagTypes qw( ComponentChildTag );
-use MooseX::Types::Moose qw( Str Maybe Int ArrayRef Undef );
+use MooseX::Types::Moose qw( Str Maybe Int );
 use WiX3::Util::StrictConstructor;
 
-our $VERSION = '0.011';
+our $VERSION = '0.009100';
+$VERSION =~ s/_//ms;
 
 # http://wix.sourceforge.net/manual-wix3/wix_xsd_component.htm
 
@@ -23,11 +23,6 @@ with qw(WiX3::XML::Role::TagAllowsChildTags
   WiX3::Role::Traceable
 );
 
-## Environment, File, RegistryKey, RegistryValue, RemoveFolder, Shortcut
-## are ComponentChildTags at the moment.
-
-has '+child_tags' => ( isa => ArrayRef [ComponentChildTag] );
-
 ## Allows lots of children: Choice of elements AppId, Category, Class,
 ## Condition, CopyFile, CreateFolder, Environment, Extension, File, IniFile,
 ## Interface, IsolateComponent, ODBCDataSource, ODBCDriver, ODBCTranslator,
@@ -38,6 +33,7 @@ has '+child_tags' => ( isa => ArrayRef [ComponentChildTag] );
 
 #####################################################################
 # Accessors:
+#   None.
 
 has id => (
 	is      => 'ro',
@@ -65,10 +61,9 @@ has directory => (
 
 has disableregistryreflection => (
 	is      => 'ro',
-	isa     => YesNoType | Undef,
+	isa     => Maybe [YesNoType],
 	reader  => '_get_disableregistryreflection',
 	default => undef,
-	coerce  => 1,
 );
 
 has diskid => (
@@ -96,10 +91,9 @@ has guid => (
 
 has keypath => (
 	is      => 'ro',
-	isa     => YesNoType | Undef,
+	isa     => Maybe [YesNoType],
 	reader  => '_get_keypath',
 	default => undef,
-	coerce  => 1,
 );
 
 has location => (
@@ -111,10 +105,9 @@ has location => (
 
 has neveroverwrite => (
 	is      => 'ro',
-	isa     => YesNoType | Undef,
+	isa     => Maybe [YesNoType],
 	reader  => '_get_neveroverwrite',
 	default => undef,
-	coerce  => 1,
 );
 
 has path => (
@@ -126,54 +119,48 @@ has path => (
 
 has permanent => (
 	is      => 'ro',
-	isa     => YesNoType | Undef,
+	isa     => Maybe [YesNoType],
 	reader  => '_get_permanent',
 	default => undef,
-	coerce  => 1,
 );
 
 # Shared requires Windows Installer 4.5
 
 has shared => (
 	is      => 'ro',
-	isa     => YesNoType | Undef,
+	isa     => Maybe [YesNoType],
 	reader  => '_get_shared',
 	default => undef,
-	coerce  => 1,
 );
 
 has shareddllrefcount => (
 	is      => 'ro',
-	isa     => YesNoType | Undef,
+	isa     => Maybe [YesNoType],
 	reader  => '_get_shareddllrefcount',
 	default => undef,
-	coerce  => 1,
 );
 
 has transitive => (
 	is      => 'ro',
-	isa     => YesNoType | Undef,
+	isa     => Maybe [YesNoType],
 	reader  => '_get_transitive',
 	default => undef,
-	coerce  => 1,
 );
 
 # UninstallWhenSuperceded requires Windows Installer 4.5
 
 has uninstallwhensuperceded => (
 	is      => 'ro',
-	isa     => YesNoType | Undef,
+	isa     => Maybe [YesNoType],
 	reader  => '_get_uninstallwhensuperceded',
 	default => undef,
-	coerce  => 1,
 );
 
 has win64 => (
 	is      => 'ro',
-	isa     => YesNoType | Undef,
+	isa     => Maybe [YesNoType],
 	reader  => '_get_win64',
 	default => undef,
-	coerce  => 1,
 );
 
 #####################################################################
