@@ -1,21 +1,21 @@
 package WiX3::XML::Directory;
 
-use 5.008003;
+use 5.008001;
 
 # Must be done before Moose, or it won't get picked up.
 use metaclass (
 	metaclass   => 'Moose::Meta::Class',
 	error_class => 'WiX3::Util::Error',
 );
-use Moose 2;
-use MooseX::Types::Moose qw( Int Str Maybe ArrayRef );
+use Moose;
+use MooseX::Types::Moose qw( Int Str Maybe );
 use WiX3::Types qw( ComponentGuidType );
-use WiX3::XML::TagTypes qw( DirectoryChildTag );
 use WiX3::Util::StrictConstructor;
 use Params::Util qw( _IDENTIFIER _STRING );
 use File::Spec::Functions qw( catdir );
 
-our $VERSION = '0.011';
+our $VERSION = '0.009100';
+$VERSION =~ s/_//ms;
 
 with qw(WiX3::XML::Role::TagAllowsChildTags
   WiX3::XML::Role::GeneratesGUID
@@ -23,10 +23,6 @@ with qw(WiX3::XML::Role::TagAllowsChildTags
 );
 
 ## Allows Component, Directory, Merge, and SymbolPath as children.
-## SymbolPath will need added later.
-
-has '+child_tags' => ( isa => ArrayRef [DirectoryChildTag] );
-
 
 #####################################################################
 # Accessors:
@@ -95,7 +91,7 @@ has sourcename => (
 
 has _shortname => (
 	is       => 'ro',
-	isa      => Maybe [Str],           # ShortFileNameType
+	isa      => Str,                   # ShortFileNameType
 	reader   => '_get_shortname',
 	init_arg => 'shortname',
 	default  => undef,
@@ -103,7 +99,7 @@ has _shortname => (
 
 has _shortsourcename => (
 	is       => 'ro',
-	isa      => Maybe [Str],           # ShortFileNameType
+	isa      => Str,                   # ShortFileNameType
 	reader   => '_get_shortsourcename',
 	init_arg => 'shortsourcename',
 	default  => undef,
@@ -174,7 +170,6 @@ sub add_directory {
 	}
 
 	my $name = $args{name};
-	## no critic(ProhibitMagicNumbers)
 	$self->trace_line( 3, "Adding directory $name\n" ) if defined $name;
 
 	# We make a new $class, rather than a new WiX3::XML::Directory,
