@@ -7,20 +7,21 @@ package WiX3::XML::Environment;
 #
 # License is the same as perl. See WiX3.pm for details.
 #
-use 5.008003;
+use 5.008001;
 
 # Must be done before Moose, or it won't get picked up.
 use metaclass (
 	metaclass   => 'Moose::Meta::Class',
 	error_class => 'WiX3::Util::Error',
 );
-use Moose 2;
+use Moose;
 use Params::Util qw( _IDENTIFIER _STRING );
-use WiX3::Types qw( YesNoType EnumEnvironmentAction);
+use WiX3::Types qw( YesNoType );
 use MooseX::Types::Moose qw( Str Maybe );
 use WiX3::Util::StrictConstructor;
 
-our $VERSION = '0.011';
+our $VERSION = '0.009100';
+$VERSION =~ s/_//ms;
 
 # http://wix.sourceforge.net/manual-wix3/wix_xsd_environment.htm
 
@@ -57,7 +58,7 @@ has value => (
 
 has action => (
 	is      => 'ro',
-	isa     => EnumEnvironmentAction,
+	isa     => Str,
 	reader  => '_get_action',
 	default => 'set',
 );
