@@ -1,19 +1,19 @@
 package WiX3::XML::File;
 
-use 5.008003;
+use 5.008001;
 
 # Must be done before Moose, or it won't get picked up.
 use metaclass (
 	metaclass   => 'Moose::Meta::Class',
 	error_class => 'WiX3::Util::Error',
 );
-use Moose 2;
+use Moose;
 use WiX3::Types qw( YesNoType PositiveInt NonNegativeInt );
-use WiX3::XML::TagTypes qw( ShortcutTag );
-use MooseX::Types::Moose qw( Str Maybe Int ArrayRef );
+use MooseX::Types::Moose qw( Str Maybe Int );
 use WiX3::Util::StrictConstructor;
 
-our $VERSION = '0.011';
+our $VERSION = '0.009100';
+$VERSION =~ s/_//ms;
 
 with 'WiX3::XML::Role::TagAllowsChildTags';
 
@@ -23,15 +23,12 @@ with 'WiX3::XML::Role::TagAllowsChildTags';
 # ODBCDriver, ODBCTranslator, Permission, PermissionEx, Shortcut, SymbolPath,
 # TypeLib
 
-has '+child_tags' => ( isa => ArrayRef [ShortcutTag] );
-
-
 #####################################################################
 # Attributes:
 
 has _assembly => (
 	is       => 'ro',
-	isa      => Maybe [Str],           # '.net', 'no', or 'win32'
+	isa      => Str,                   # '.net', 'no', or 'win32'
 	reader   => '_get_assembly',
 	init_arg => 'assembly',
 	default  => undef,
@@ -39,7 +36,7 @@ has _assembly => (
 
 has _assemblyapplication => (
 	is       => 'ro',
-	isa      => Maybe [Str],
+	isa      => Str,
 	reader   => '_get_assemblyapplication',
 	init_arg => 'assemblyapplication',
 	default  => undef,
@@ -47,7 +44,7 @@ has _assemblyapplication => (
 
 has _assemblymanifest => (
 	is       => 'ro',
-	isa      => Maybe [Str],
+	isa      => Str,
 	reader   => '_get_assemblymanifest',
 	init_arg => 'assemblymanifest',
 	default  => undef,
@@ -55,7 +52,7 @@ has _assemblymanifest => (
 
 has _bindpath => (
 	is       => 'ro',
-	isa      => Maybe [Str],
+	isa      => Str,
 	reader   => '_get_bindpath',
 	init_arg => 'bindpath',
 	default  => undef,
@@ -150,7 +147,7 @@ has _keypath => (
 
 has name => (
 	is      => 'ro',
-	isa     => Maybe [Str],            # LongNameFileType
+	isa     => Str,                    # LongNameFileType
 	reader  => 'get_name',
 	default => undef,
 );
@@ -189,7 +186,7 @@ has _patchgroup => (
 
 has _processorarchitecture => (
 	is     => 'ro',
-	isa    => Maybe [Str],             # 'msil', 'x86', 'x64', or 'ia64'
+	isa    => Str,                     # 'msil', 'x86', 'x64', or 'ia64'
 	reader => '_get_processorarchitecture',
 	init_arg => 'processorarchitecture',
 	default  => undef,
@@ -205,7 +202,7 @@ has _readonly => (
 
 has _selfregcost => (
 	is       => 'ro',
-	isa      => Maybe [Int],
+	isa      => 'Int',
 	reader   => '_get_selfregcost',
 	init_arg => 'selfregcost',
 	default  => undef,
@@ -213,7 +210,7 @@ has _selfregcost => (
 
 has _shortname => (
 	is       => 'ro',
-	isa      => Maybe [Str],           # ShortFileNameType
+	isa      => 'Str',                 # ShortFileNameType
 	reader   => '_get_shortname',
 	init_arg => 'shortname',
 	default  => undef,
@@ -221,7 +218,7 @@ has _shortname => (
 
 has _source => (
 	is       => 'ro',
-	isa      => Maybe [Str],
+	isa      => 'Str',
 	reader   => '_get_source',
 	init_arg => 'source',
 	default  => undef,
