@@ -1,11 +1,15 @@
 package WiX3::XML::Role::Tag;
 
-use 5.008003;
-use Moose::Role 2;
+use 5.008001;
+use Moose::Role;
 use Params::Util qw( _STRING _NONNEGINT );
 use WiX3::Exceptions;
+require WiX3::XML::ComponentRef;
+require WiX3::XML::FeatureRef;
+require WiX3::XML::MergeRef;
 
-our $VERSION = '0.011';
+our $VERSION = '0.009100';
+$VERSION =~ s/_//ms;
 
 #####################################################################
 # Methods
@@ -63,17 +67,14 @@ sub get_componentref_array {
 	my $count = $self->count_child_tags();
 
 	if ( $self->isa('WiX3::XML::Component') ) {
-		require WiX3::XML::ComponentRef;
 		return WiX3::XML::ComponentRef->new($self);
 	}
 
 	if ( $self->isa('WiX3::XML::Feature') ) {
-		require WiX3::XML::FeatureRef;
 		return WiX3::XML::FeatureRef->new($self);
 	}
 
 	if ( $self->isa('WiX3::XML::Merge') ) {
-		require WiX3::XML::MergeRef;
 		return WiX3::XML::MergeRef->new($self);
 	}
 
@@ -107,11 +108,7 @@ sub print_attribute {
 		return q{};
 	}
 
-	if ( $value =~ m{[']}ms ) {
-		return qq{ $attribute="$value"};
-	} else {
-		return qq{ $attribute='$value'};
-	}
+	return qq{ $attribute='$value'};
 
 } ## end sub print_attribute
 
@@ -127,11 +124,11 @@ WiX3::XML::Role::Tag - Base role for XML tags.
 
 =head1 VERSION
 
-This document describes WiX3::XML::Role::Tag version 0.009102
+This document describes WiX3::XML::Role::Tag version 0.009100
 
 =head1 SYNOPSIS
 
-	# This is composed in to other tag classes.
+    # use WiX3;
 
 =head1 DESCRIPTION
 
